/**
 * @file ctmatlab.h
 *
 * @deprecated  Deprecated in %Cantera 3.2 and to be removed thereafter.
 *      The legacy CLib is superseded by the generated CLib.
 */

// This file is part of Cantera. See License.txt in the top-level directory or
// at https://cantera.org/license.txt for license and copyright information.

#pragma message("warning: The legacy CLib library ctmatlab.h is deprecated and " \
                "will be removed after Cantera 3.2.")

#include "ct.h"
#include "ctfunc.h"
#include "ctmultiphase.h"
#include "ctonedim.h"
#include "ctreactor.h"
#include "ctrpath.h"
#include "ctsurf.h"
